@@ -8,6 +8,7 @@ __version__ = VERSION
 write_key = None
 on_error = None
 debug = False
+send = True
 
 default_client = None
 
@@ -44,7 +45,8 @@ def _proxy(method, *args, **kwargs):
     """Create an analytics client if one doesn't exist and send to it."""
     global default_client
     if not default_client:
-        default_client = Client(write_key, debug=debug, on_error=on_error)
+        default_client = Client(write_key, debug=debug, on_error=on_error,
+                                send=send)
 
     fn = getattr(default_client, method)
     fn(*args, **kwargs)
